.. include:: ../README.rst


.. toctree::
   :maxdepth: 1
   :caption: User Guide

   API <api/pysensors>
   Examples <examples/index>

.. toctree::
   :maxdepth: 1
   :caption: Useful links


   PySensors @ PyPI <https://pypi.org/project/python-sensors/>
   Issue Tracker <https://github.com/dynamicslab/pysensors/issues>